[![PyPI version](https://badge.fury.io/py/qtwirl.svg)](https://badge.fury.io/py/qtwirl) [![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.1342743.svg)](https://doi.org/10.5281/zenodo.1342743) [![Build Status](https://travis-ci.org/alphatwirl/qtwirl.svg?branch=master)](https://travis-ci.org/alphatwirl/qtwirl) [![codecov](https://codecov.io/gh/alphatwirl/qtwirl/branch/master/graph/badge.svg)](https://codecov.io/gh/alphatwirl/qtwirl)

# qtwirl

qtwirl (quick-twirl), one-function interface to [AlphaTwirl](https://github.com/alphatwirl/alphatwirl)

***

### Quick start

- Jupyter Notebook: [*Quick start of AlphaTwirl*](https://github.com/alphatwirl/notebook-tutorial-2019-02)<br />

&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;[![Binder](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/alphatwirl/notebook-tutorial-2019-02/master?filepath=tutorial_01.ipynb)

***
